pub struct UpdateChecker { /* private fields */ }Available on crate feature
blocking only.Expand description
Synchronous update checker for configuring and executing an update check against a GitHub repo.
Uses nyquest::BlockingClient directly — no async runtime or
[futures::executor::block_on] involved.
Example
nyquest_preset::register();
let checker = ib_update::github::UpdateConfig::builder()
.owner("owner")
.repo("repo")
.current_version("1.0.0")
.token("ghp_...")
.build_blocking();
let info = checker.check()?;
println!("Latest: {}, update available: {}", info.latest().tag, info.has_update());Implementations
Sourceimpl UpdateChecker
impl UpdateChecker
Sourcepub fn new(config: UpdateConfig) -> Self
pub fn new(config: UpdateConfig) -> Self
Create a UpdateChecker from a built UpdateConfig.
Sourcepub fn fetch_latest(&self) -> Result<Release, Error>
pub fn fetch_latest(&self) -> Result<Release, Error>
Fetch the latest release from GitHub.
Sourcepub fn fetch(&self, n: usize) -> Result<Vec<Release>, Error>
pub fn fetch(&self, n: usize) -> Result<Vec<Release>, Error>
Fetch up to n releases (including pre-releases) from GitHub.
n: Must be <= 100 at the moment.
Sourcepub fn fetch_latest_prerelease(&self) -> Result<Release, Error>
pub fn fetch_latest_prerelease(&self) -> Result<Release, Error>
Fetch the latest release, including pre-releases.
Sourcepub fn check(&self) -> Result<UpdateInfo, Error>
pub fn check(&self) -> Result<UpdateInfo, Error>
Execute the update check.
Fetches the latest release from GitHub and compares it against the current version (if set).
Sourcepub fn check_prerelease(&self, prerelease: bool) -> Result<UpdateInfo, Error>
pub fn check_prerelease(&self, prerelease: bool) -> Result<UpdateInfo, Error>
Execute the update check, optionally including pre-releases.
You likely want to use !env!("CARGO_PKG_VERSION_PRE").is_empty() as the default value.