pub struct UpdateInfo { /* private fields */ }Expand description
Result of an update check — contains the latest release and comparison info.
Implementations
Sourceimpl UpdateInfo
impl UpdateInfo
Sourcepub fn current_version(&self) -> Option<&str>
pub fn current_version(&self) -> Option<&str>
Returns the current version that was compared against, if any was provided.
Sourcepub fn has_update(&self) -> bool
pub fn has_update(&self) -> bool
Returns true if an update is recommended.
This is true when:
- No
current_versionwas set (any release is “new”), or - The latest version is strictly greater than the current version
(compared via
semverwhen both parse, otherwise lexicographically).