GitHub Releases update source.
This module queries the GitHub REST API for the latest release of a given repository and compares it against the current version to determine whether an update is available.
Structs
- Async
Update Checker async - Async builder for configuring and executing an update check against a GitHub repo.
- Release
- A GitHub release as returned by the
/releases/latestendpoint. - Release
Asset - A single release asset (binary, archive, etc.) attached to a GitHub release.
- Update
Checker blocking - Synchronous update checker for configuring and executing an update check against a GitHub repo.
- Update
Config - Shared configuration for update checks — contains no I/O logic.
- Update
Config Builder - Use builder syntax to set the inputs and finish with
build(). - Update
Info - Result of an update check — contains the latest release and comparison info.
Enums
- Error
- Errors that can occur during an update check.