pub struct AsyncUpdateChecker { /* private fields */ }Available on crate feature
async only.Expand description
Async builder for configuring and executing an update check against a GitHub repo.
Example
nyquest_preset::register();
futures::executor::block_on(async {
let checker = ib_update::github::UpdateConfig::builder()
.owner("owner")
.repo("repo")
.current_version("1.0.0")
.token("ghp_...")
.build_async();
let info = checker.check().await?;
println!("Latest: {}, update available: {}", info.latest().tag, info.has_update());
Ok(())
})Implementations
Sourceimpl AsyncUpdateChecker
impl AsyncUpdateChecker
Sourcepub fn new(config: UpdateConfig) -> Self
pub fn new(config: UpdateConfig) -> Self
Create an AsyncUpdateChecker from a built UpdateConfig.
Sourcepub async fn fetch_latest(&self) -> Result<Release, Error>
pub async fn fetch_latest(&self) -> Result<Release, Error>
Fetch the latest release from GitHub.
Sourcepub async fn fetch(&self, n: usize) -> Result<Vec<Release>, Error>
pub async fn fetch(&self, n: usize) -> Result<Vec<Release>, Error>
Fetch up to n releases (including pre-releases) from GitHub.
n: Must be <= 100 at the moment.
Sourcepub async fn fetch_latest_prerelease(&self) -> Result<Release, Error>
pub async fn fetch_latest_prerelease(&self) -> Result<Release, Error>
Fetch the latest release, including pre-releases.
Sourcepub async fn check(&self) -> Result<UpdateInfo, Error>
pub async fn check(&self) -> Result<UpdateInfo, Error>
Execute the update check.
Fetches the latest release from GitHub and compares it against the current version (if set).
Sourcepub async fn check_prerelease(
&self,
prerelease: bool,
) -> Result<UpdateInfo, Error>
pub async fn check_prerelease( &self, prerelease: bool, ) -> Result<UpdateInfo, Error>
Execute the update check, optionally including pre-releases.
You likely want to use !env!("CARGO_PKG_VERSION_PRE").is_empty() as the default value.